show_stats: Show statistics for all the columns of a data frame

Description Usage

View source: R/utils.R

Description

Show statistics for all the columns of a data frame

Usage

1
show_stats(df, digits = 3, use_percent = F, max_levels = 6, dropna = F)

yajiez/metabor documentation built on Feb. 24, 2020, 2 a.m.